/*
** Module   : DataModelTokenTypes.java
** Abstract : Token types for a data model-specific AST.
**
** Copyright (c) 2005-2012, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -T- --JPRM-- ----------------Description-----------------
** 001 ECF 20050426 ADD   @21001 Created initial version.
** 002 ECF 20050608 CHG   @21462 Removed unused token types.
** 003 ECF 20050616 CHG   @21537 Added relation types: MANY_TO_ONE, ONE_TO_ONE
**                               and ONE_TO_MANY.
** 004 ECF 20050628 CHG   @21604 Added COMPONENT type.
** 005 ECF 20050707 CHG   @21672 Added tokens needed for initial value
**                               processing. INITIAL, STRING, NUM_LITERAL,
**                               DEC_LITERAL, BOOL_TRUE, BOOL_FALSE,
**                               DATE_LITERAL, UNKNOWN.
** 006 ECF 20050720 CHG   @21774 Changed COMPONENT to COMPOSITE.
** 007 ECF 20060401 CHG   @25333 Added NULL_LITERAL.
** 008 OM  20121207              Added support for sequence nodes to p2j file.
*/

package com.goldencode.p2j.schema;

/**
 * Token types necessary to represent a data model as an AST.
 */
public interface DataModelTokenTypes
{
   /** Root AST for the data model */
   public static final int DATA_MODEL = 1;
   
   /** Database table */
   public static final int TABLE = 2;
   
   /** Instance variable property of data model class representing a column */
   public static final int PROPERTY = 3;
   
   /** Data model class */
   public static final int CLASS = 4;
   
   /** Unique identifier generator for primary keys */
   public static final int GENERATOR = 5;
   
   /** Primary key */
   public static final int PRIMARY = 6;
   
   /** Foreign key */
   public static final int FOREIGN = 7;
   
   /** Database table index */
   public static final int INDEX = 8;
   
   /** Unique constraint */
   public static final int UNIQUE = 9;
   
   /** Column participating in an index */
   public static final int INDEX_COL = 10;
   
   /** Column participating in a constraint */
   public static final int CONSTR_COL = 11;
   
   /** Many-to-one relationship */
   public static final int MANY_TO_ONE = 12;
   
   /** One-to-many relationship */
   public static final int ONE_TO_MANY = 13;
   
   /** One-to-one relationship */
   public static final int ONE_TO_ONE = 14;
   
   /** Property composite */
   public static final int COMPOSITE = 15;
   
   /** Initial value */
   public static final int INITIAL = 16;
   
   /** String literal */
   public static final int STRING = 17;
   
   /** Integral literal */
   public static final int NUM_LITERAL = 18;
   
   /** Decimal literal */
   public static final int DEC_LITERAL = 19;
   
   /** Boolean true literal */
   public static final int BOOL_TRUE = 20;
   
   /** Boolean false literal */
   public static final int BOOL_FALSE = 21;
   
   /** Date literal */
   public static final int DATE_LITERAL = 22;
   
   /** Unknown value literal */
   public static final int UNKNOWN = 23;
   
   /** Null literal */
   public static final int NULL_LITERAL = 24;
   
   /** Sequence literal */
   public static final int SEQUENCE = 25;
}
